# -----------------------------------------------------------------------------
# set-up
# -----------------------------------------------------------------------------
input_folder <- "data/input/"
output_folder <- "data/output/"
# -----------------------------------------------------------------------------
# import data
# -----------------------------------------------------------------------------
survey <- read_csv(
    here(
        input_folder,
        "Pesquisa sobre Ética e Corrupção no Serviço Público_WIDE.csv"
    ),
    locale = locale(encoding = "UTF-8")
)

colnames(survey) <- colnames(survey) %>% 
    str_replace_all("\\.", "")

label_dictionary <- read_csv(
    here(input_folder, "table_variable_labels.csv")
)

# ==============================================================================
# replace values with labels
# ==============================================================================
cols_with_labels <- colnames(survey) %>% 
    str_subset("_label$")

cols_without_labels <- cols_with_labels %>% 
    str_replace("_label$", "")

# drop columns without labels
cols_dictionary_vector <- cols_with_labels
names(cols_dictionary_vector) <- cols_without_labels

# rename columns with labels
survey <- survey %>% 
    select(-cols_without_labels) %>%
    rename(
        !!all_of(cols_dictionary_vector)
    )

# ==============================================================================
# eliminate non-consent and incomplete responses
# ==============================================================================
# only retain when consented
consent <- "Eu concordo em participar da pesquisa"

survey <- survey %>%
    filter(
        consent_q1 == consent
    )

# eliminate defective entries and non-response
survey <- survey %>% 
    filter(
        !is.na(idn_1) &
        !(idn_1 == "Não sou agente público") &
        !(idn_1 == "Prefiro não responder" & as.numeric(idn_2) > 5)
    )

# ==============================================================================
# convert special characters
# ==============================================================================
survey <- survey %>%
    mutate(
        across(
            where(is.character) & !matches("^ministerio|^idn"),
            convert_to_ascii
        )
    )

# ==============================================================================
# clean experiment data: scenarios
# ==============================================================================
# subset columns to experimental data
experiment_norms <- survey %>% 
    select(
        KEY,
        starts_with("sna"),
        starts_with("snb")
    )

# generate treatment arms
experiment_norms <- experiment_norms %>%
    pivot_longer(
        cols = -KEY,
        names_to = "exp_norms_treatment",
        values_to = "exp_norms_response"
    ) %>%
    filter(!is.na(exp_norms_response))

# classify treatment branches
experiment_norms <- experiment_norms %>%
    mutate(
        exp_norms_branch = if_else(
            str_detect(exp_norms_treatment, "^sna"),
            "A", "B"
        )
    )
    
# relabel treatments
experiment_norms <- experiment_norms %>%
    mutate(
        exp_norms_treatment = case_when(
            str_detect(exp_norms_treatment, "^sna1") ~ "controle",
            str_detect(exp_norms_treatment, "^sna2") ~ "promoção de carreira",
            str_detect(exp_norms_treatment, "^sna3") ~ "pressão do superior",
            str_detect(exp_norms_treatment, "^snb1") ~ "controle",
            str_detect(exp_norms_treatment, "^snb2") ~ "troca de favores",
            str_detect(exp_norms_treatment, "^snb3") ~ "ajudar ong",
            str_detect(exp_norms_treatment, "^snb4") ~ "suborno",
            str_detect(exp_norms_treatment, "^snb5") ~ "suborno em necessidade",
            str_detect(exp_norms_treatment, "^snb6") ~ "suborno comum",
            T ~ NA_character_
        )
    )

# convert answers to ordinate scale
experiment_norms <- experiment_norms %>%
    mutate(
        exp_norms_response = case_when(
                str_detect(exp_norms_response, "nao justificavel|Não justificável") ~ 1,
                str_detect(exp_norms_response, "nao justificavel|Justificável") ~ 5,
                str_detect(exp_norms_response, "prefiro nao responder|Prefiro não responder") ~ NA_real_,
                T ~ as.numeric(exp_norms_response)
        )
    )

# drop experiment columns
survey <- survey %>%
    select(
        -starts_with("sna"),
        -starts_with("snb")
    )

# rejoin data with original survey
survey <- survey %>%
    left_join(
        experiment_norms,
        by = "KEY"
    )

# ==============================================================================
# rename column names
# ==============================================================================
# generate vector to replace colnames
label_dictionary_vector <- label_dictionary %>%
    filter(
        !is.na(new_variable)
    ) %>%
    select(
        new_variable, variable
    ) %>%
    deframe()

# rename columns with intuitive names
survey_renamed <- survey %>%
    rename(
        !!label_dictionary_vector
    )

# ==============================================================================
# output data
# ==============================================================================
survey_renamed %>% 
    write_csv(
        here(output_folder, "survey_clean.csv")
    )

survey %>% 
    write_csv(
        here(output_folder, "survey_clean_original_labels.csv")
    )
